@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2019-2020                                               *
- *                  by Nikolai Krasheninnikov <nkrasheninnikov@yandex.ru>  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2019-2020 Nikolai Krasheninnikov <nkrasheninnikov@yandex.ru>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "svncommands.h"
 
@@ -118,7 +104,7 @@ QString SvnCommands::remoteItemUrl(const QString& filePath)
     );
 
     if (!process.waitForFinished() || process.exitCode() != 0) {
-        return 0;
+        return nullptr;
     }
 
     QTextStream stream(&process);
@@ -147,7 +133,7 @@ QString SvnCommands::remoteRootUrl(const QString& filePath)
     );
 
     if (!process.waitForFinished() || process.exitCode() != 0) {
-        return 0;
+        return nullptr;
     }
 
     QTextStream stream(&process);
@@ -176,7 +162,7 @@ QString SvnCommands::remoteRelativeUrl(const QString& filePath)
     );
 
     if (!process.waitForFinished() || process.exitCode() != 0) {
-        return 0;
+        return nullptr;
     }
 
     QTextStream stream(&process);
@@ -205,7 +191,7 @@ QString SvnCommands::localRoot(const QString& filePath)
     );
 
     if (!process.waitForFinished() || process.exitCode() != 0) {
-        return 0;
+        return nullptr;
     }
 
     QTextStream stream(&process);
